summaryrefslogtreecommitdiff
path: root/src/Persistent_cohomology/concept/FilteredComplex.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Persistent_cohomology/concept/FilteredComplex.h')
-rw-r--r--src/Persistent_cohomology/concept/FilteredComplex.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/Persistent_cohomology/concept/FilteredComplex.h b/src/Persistent_cohomology/concept/FilteredComplex.h
index 1834903b..e124d524 100644
--- a/src/Persistent_cohomology/concept/FilteredComplex.h
+++ b/src/Persistent_cohomology/concept/FilteredComplex.h
@@ -65,9 +65,9 @@ struct FilteredComplex
Simplex_key key ( Simplex_handle sh );
/** \brief Returns the simplex associated to a key.
*
- * If key is different from null_key(), there must be a unique
- * simplex having this key. */
- Simplex_handle simplex ( Simplex_key key );
+ * If key is different from null_key(), returns the simplex that
+ * has index idx in the filtration. */
+ Simplex_handle simplex ( Simplex_key idx );
/** \brief Assign a key to a simplex. */
void assign_key(Simplex_handle sh, Simplex_key key);